@@ -1,6 +1,8 @@
 //#include <config.h>
 #include "DNormOV.h"
 
+#include <TruncatedNormal.h>
+
 #include <cmath>
 
 #include <JRmath.h>
@@ -12,12 +14,10 @@ using std::vector;
 #define TAU(par) (*par[1])
 
 DNormOV::DNormOV()
-    : DistScalarRmath("dnormOV", 2, DIST_UNBOUNDED, true, false)
+    : RScalarDist("dnormOV", 2, DIST_UNBOUNDED)
 {}
 
-bool DNormOV::checkParameterValue (vector<double const *> const &par,
-				 vector<vector<unsigned int> > const &dims) 
-  const
+bool DNormOV::checkParameterValue (vector<double const *> const &par) const
 {
     return (TAU(par) > 0);
 }
@@ -48,3 +48,27 @@ DNormOV::r(vector<double const *> const &par, RNG *rng) const
     return rnorm(MU(par), SIGMA(par), rng);
 }
 
+double DNormOV::randomSample(vector<double const *> const &par,
+			   double const *lower, double const *upper,
+			   RNG *rng) const
+{
+    double mu = MU(par);
+    double sigma = SIGMA(par);
+    
+    if (lower && upper) {
+	double left = (*lower - mu)/sigma;
+	double right = (*upper - mu)/sigma;
+	return mu + sigma * inormal(left, right, rng);
+    }
+    else if (lower) {
+	double left = (*lower - mu)/sigma;
+	return mu + sigma * lnormal(left, rng);
+    }
+    else if (upper) {
+	double right = (*upper - mu)/sigma;
+	return mu + sigma * rnormal(right, rng);
+    }
+    else {
+	return rnorm(mu, sigma, rng);
+    }
+}
