@@ -4,7 +4,8 @@
 //#include "DiscreteSlicer.h"
 #include "SliceFactoryOV.h"
 
-#include <sampler/DensitySampler.h>
+#include <sampler/ParallelSampler.h>
+#include <sampler/SampleMethod.h>
 #include <graph/StochasticNode.h>
 #include <distribution/Distribution.h>
 
@@ -20,20 +21,30 @@ SliceFactoryOV::canSample(StochasticNode * node, Graph const &graph) const
     return RealSlicerOV::canSample(node);
 }
 
-Sampler *SliceFactoryOV::makeSingletonSampler(StochasticNode *snode,
-					      Graph const &graph) const
+Sampler *SliceFactoryOV::makeSampler(StochasticNode *snode,
+				     Graph const &graph) const
 {
     unsigned int nchain = snode->nchain();
-    vector<DensityMethod*> methods(nchain, 0);
+    vector<SampleMethod*> methods(nchain, 0);
+
+    vector<StochasticNode*> sv;
+    sv.push_back(snode);
+    GraphView * gv = new GraphView(sv, graph);
     
     for (unsigned int ch = 0; ch < nchain; ++ch) {
 
-	methods[ch] = new RealSlicerOV();
+	methods[ch] = new RealSlicerOV(gv, ch);
 
     }
     
     vector<StochasticNode*> nodes(1, snode);
-    return new DensitySampler(nodes, graph, methods);
+    return new ParallelSampler(gv,  methods);
+}
+
+std::string SliceFactoryOV::name() const
+{
+    return "SliceFactoryOV";
 }
 
 
+
